yt.utilities.lib.geometry\_utils module
=======================================

.. automodule:: yt.utilities.lib.geometry_utils
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
